@@ -80,7 +80,20 @@ class AwsCliAsset(
         :param ignore_mode: The ignore behavior to use for exclude patterns. Default: IgnoreMode.GLOB
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AwsCliAsset.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                readers: typing.Optional[typing.Sequence[aws_cdk.aws_iam.IGrantable]] = None,
+                asset_hash: typing.Optional[builtins.str] = None,
+                asset_hash_type: typing.Optional[aws_cdk.AssetHashType] = None,
+                bundling: typing.Optional[typing.Union[aws_cdk.BundlingOptions, typing.Dict[str, typing.Any]]] = None,
+                exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
+                follow_symlinks: typing.Optional[aws_cdk.SymlinkFollowMode] = None,
+                ignore_mode: typing.Optional[aws_cdk.IgnoreMode] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         options = aws_cdk.aws_s3_assets.AssetOptions(
